@@ -28,21 +28,21 @@ the :class:`Compound` class inherits from the builtin ``dict`` type.
 This means that all the familiar operations available on the base type
 work out of the box on the derived tag instances.
 
-+-------------------+------------------------------------------------------------+
-|     Base type     |                    Associated nbt tags                     |
-+===================+============================================================+
-| ``int``           | :class:`Byte`, :class:`Short`, :class:`Int`, :class:`Long` |
-+-------------------+------------------------------------------------------------+
-| ``float``         | :class:`Float`, :class:`Double`                            |
-+-------------------+------------------------------------------------------------+
-| ``str``           | :class:`String`                                            |
-+-------------------+------------------------------------------------------------+
-| ``numpy.ndarray`` | :class:`ByteArray`, :class:`IntArray`, :class:`LongArray`  |
-+-------------------+------------------------------------------------------------+
-| ``list``          | :class:`List`                                              |
-+-------------------+------------------------------------------------------------+
-| ``dict``          | :class:`Compound`                                          |
-+-------------------+------------------------------------------------------------+
++-------------------+---------------------------------------------------------+
+|     Base type     |                   Associated nbt tags                   |
++===================+=========================================================+
+| ``int``           | :class:`Byte` :class:`Short` :class:`Int` :class:`Long` |
++-------------------+---------------------------------------------------------+
+| ``float``         | :class:`Float` :class:`Double`                          |
++-------------------+---------------------------------------------------------+
+| ``str``           | :class:`String`                                         |
++-------------------+---------------------------------------------------------+
+| ``numpy.ndarray`` | :class:`ByteArray` :class:`IntArray` :class:`LongArray` |
++-------------------+---------------------------------------------------------+
+| ``list``          | :class:`List`                                           |
++-------------------+---------------------------------------------------------+
+| ``dict``          | :class:`Compound`                                       |
++-------------------+---------------------------------------------------------+
 
 Operator overloading works as expected with all tag types. Note that values are
 returned unwrapped.
@@ -782,7 +782,7 @@ class List(Base, list):
             return cls.variants[item]
         except KeyError:
             variant = type(
-                f"List[{item.__name__}]", (List,), {"__slots__": (), "subtype": item},
+                f"List[{item.__name__}]", (List,), {"__slots__": (), "subtype": item}
             )
             cls.variants[item] = variant
             return variant
